==> mule-tooling-api-1.3.0-20220919-sources.jar: org/mule/tooling/client/api/types/Transaction.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.tooling.client.api.types;

import org.mule.tooling.client.api.message.history.MessageHistory;
import org.mule.tooling.event.model.MessageModel;

import java.util.ArrayList;
import java.util.List;

/**
 * A {@link Transaction} from {@link MessageHistory} represents a whole execution
 * for a Mule application and the {@link TransactionStackEntry entries} represents the data at each component.
 *
 * @since 1.0
 */
public class Transaction {

  private String id;
  private MessageModel message;
  private long timestamp;
  private List<TransactionStackEntry> transactionStack = new ArrayList<>();
  private TransactionStatus transactionStatus;
  private String globalName;

  public void setId(String id) {
    this.id = id;
  }

  public void setTransactionStack(List<TransactionStackEntry> transactionStack) {
    this.transactionStack = transactionStack;
  }

  public String getId() {
    return id;
  }

  public List<TransactionStackEntry> getTransactionStack() {
    return transactionStack;
  }

  public MessageModel getMessage() {
    return message;
  }

  public TransactionStatus getTransactionStatus() {
    return transactionStatus;
  }

  public long getTimestamp() {
    return timestamp;
  }

  public String getGlobalName() {
    return globalName;
  }

  public void setTimestamp(long timestamp) {
    this.timestamp = timestamp;
  }

  public void setMessage(MessageModel message) {
    this.message = message;
  }

  public void setTransactionStatus(TransactionStatus transactionStatus) {
    this.transactionStatus = transactionStatus;
  }

  public void setGlobalName(String globalName) {
    this.globalName = globalName;
  }
}

==> mule-tooling-api-1.4.0-20220919-sources.jar: org/mule/tooling/client/api/types/Transaction.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.tooling.client.api.types;

import org.mule.tooling.client.api.message.history.MessageHistory;
import org.mule.tooling.event.model.MessageModel;

import java.util.ArrayList;
import java.util.List;

/**
 * A {@link Transaction} from {@link MessageHistory} represents a whole execution for a Mule application and the
 * {@link TransactionStackEntry entries} represents the data at each component.
 *
 * @since 1.0
 */
public class Transaction {

  private String id;
  private MessageModel message;
  private long timestamp;
  private List<TransactionStackEntry> transactionStack = new ArrayList<>();
  private TransactionStatus transactionStatus;
  private String globalName;

  public void setId(String id) {
    this.id = id;
  }

  public void setTransactionStack(List<TransactionStackEntry> transactionStack) {
    this.transactionStack = transactionStack;
  }

  public String getId() {
    return id;
  }

  public List<TransactionStackEntry> getTransactionStack() {
    return transactionStack;
  }

  public MessageModel getMessage() {
    return message;
  }

  public TransactionStatus getTransactionStatus() {
    return transactionStatus;
  }

  public long getTimestamp() {
    return timestamp;
  }

  public String getGlobalName() {
    return globalName;
  }

  public void setTimestamp(long timestamp) {
    this.timestamp = timestamp;
  }

  public void setMessage(MessageModel message) {
    this.message = message;
  }

  public void setTransactionStatus(TransactionStatus transactionStatus) {
    this.transactionStatus = transactionStatus;
  }

  public void setGlobalName(String globalName) {
    this.globalName = globalName;
  }
}
